class QuestionsController < ApplicationController
  before_filter :should_be_signed_in
  before_filter only:[:solve, :publish, :edit, :update, :destroy] do |c|
    redirect_to :back unless Question.find(params[:id] || params[:question_id]).user == current_user
  end
  
  def publish
    @question = Question.find(params[:question_id])
    @question.publish
    redirect_to :back
  end

  def solve
    @question = Question.find(params[:question_id])
    @question.solve
    redirect_to :back
  end

  # GET /questions
  # GET /questions.json
  def index
    @questions = Question.where(state: :published).reverse

    respond_to do |format|
      format.html # index.html.erb
      format.json { render json: @questions }
    end
  end
  def tagged
    @questions = Question.tagged_with(params[:tag])
  end
  # GET /questions/1
  # GET /questions/1.json
  def show
    @question = Question.find(params[:id])
    @question.views += 1
    @question.save!
    @answer = @question.answers.new
    @answer.user = current_user
    @answer.check = 0

    respond_to do |format|
      format.html # show.html.erb
      format.json { render json: @question }
    end
  end

  # GET /questions/new
  # GET /questions/new.json
  def new
    @question = Question.new

    respond_to do |format|
      format.html # new.html.erb
      format.json { render json: @question }
    end
  end

  # GET /questions/1/edit
  def edit
    @question = Question.find(params[:id])
  end

  # POST /questions
  # POST /questions.json
  def create
    @question = Question.new(params[:question])
    @question.user = User.find(session[:user_id])

    respond_to do |format|
      if @question.save
        format.html { redirect_to @question, notice: 'Question was successfully created.' }
        format.json { render json: @question, status: :created, location: @question }
      else
        format.html { render action: "new" }
        format.json { render json: @question.errors, status: :unprocessable_entity }
      end
    end
  end

  # PUT /questions/1
  # PUT /questions/1.json
  def update
    @question = Question.find(params[:id])

    respond_to do |format|
      if @question.update_attributes(params[:question])
        format.html { redirect_to @question, notice: 'Question was successfully updated.' }
        format.json { head :no_content }
      else
        format.html { render action: "edit" }
        format.json { render json: @question.errors, status: :unprocessable_entity }
      end
    end
  end

  # DELETE /questions/1
  # DELETE /questions/1.json
  def destroy
    @question = Question.find(params[:id])
    @question.destroy

    respond_to do |format|
      format.html { redirect_to questions_url }
      format.json { head :no_content }
    end
  end
end
